.. only:: html

   .. image:: https://img.shields.io/pypi/pyversions/deltona.svg?color=blue&logo=python&logoColor=white
      :target: https://www.python.org/
      :alt: Python versions

   .. image:: https://img.shields.io/pypi/v/deltona
      :target: https://pypi.org/project/deltona/
      :alt: PyPI - Version

   .. image:: https://img.shields.io/github/v/tag/Tatsh/deltona
      :target: https://github.com/Tatsh/deltona/tags
      :alt: GitHub tag (with filter)

   .. image:: https://img.shields.io/github/license/Tatsh/deltona
      :target: https://github.com/Tatsh/deltona/blob/master/LICENSE.txt
      :alt: License

   .. image:: https://img.shields.io/github/commits-since/Tatsh/deltona/v0.1.1/master
      :target: https://github.com/Tatsh/deltona/compare/v0.1.1...master
      :alt: GitHub commits since latest release (by SemVer including pre-releases)

   .. image:: https://github.com/Tatsh/deltona/actions/workflows/codeql.yml/badge.svg
      :target: https://github.com/Tatsh/deltona/actions/workflows/codeql.yml
      :alt: CodeQL

   .. image:: https://github.com/Tatsh/deltona/actions/workflows/qa.yml/badge.svg
      :target: https://github.com/Tatsh/deltona/actions/workflows/qa.yml
      :alt: QA

   .. image:: https://github.com/Tatsh/deltona/actions/workflows/tests.yml/badge.svg
      :target: https://github.com/Tatsh/deltona/actions/workflows/tests.yml
      :alt: Tests

   .. image:: https://coveralls.io/repos/github/Tatsh/deltona/badge.svg?branch=master
      :target: https://coveralls.io/github/Tatsh/deltona?branch=master
      :alt: Coverage Status

   .. image:: https://img.shields.io/badge/Dependabot-enabled-blue?logo=dependabot
      :target: https://github.com/dependabot
      :alt: Dependabot

   .. image:: https://readthedocs.org/projects/deltona/badge/?version=latest
      :target: https://deltona.readthedocs.org/?badge=latest
      :alt: Documentation Status

   .. image:: https://www.mypy-lang.org/static/mypy_badge.svg
      :target: https://mypy-lang.org/
      :alt: mypy

   .. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit
      :target: https://pre-commit.com/
      :alt: pre-commit

   .. image:: https://img.shields.io/badge/uv-261230?logo=astral
      :target: https://docs.astral.sh/uv/
      :alt: uv

   .. image:: https://img.shields.io/badge/pydocstyle-enabled-AD4CD3?logo=pydocstyle
      :target: https://www.pydocstyle.org/
      :alt: pydocstyle

   .. image:: https://img.shields.io/badge/pytest-enabled-CFB97D?logo=pytest
      :target: https://docs.pytest.org
      :alt: pytest

   .. image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json
      :target: https://github.com/astral-sh/ruff
      :alt: Ruff

   .. image:: https://static.pepy.tech/badge/deltona/month
      :target: https://pepy.tech/project/deltona
      :alt: Downloads

   .. image:: https://img.shields.io/github/stars/Tatsh/deltona?logo=github&style=flat
      :target: https://github.com/Tatsh/deltona/stargazers
      :alt: Stargazers

   .. image:: https://img.shields.io/badge/Prettier-enabled-black?logo=prettier
      :target: https://prettier.io/
      :alt: Prettier

   .. image:: https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fpublic.api.bsky.app%2Fxrpc%2Fapp.bsky.actor.getProfile%2F%3Factor=did%3Aplc%3Auq42idtvuccnmtl57nsucz72&query=%24.followersCount&label=Follow+%40Tatsh&logo=bluesky&style=social
      :target: https://bsky.app/profile/Tatsh.bsky.social
      :alt: @Tatsh

   .. image:: https://img.shields.io/badge/Buy%20Me%20a%20Coffee-Tatsh-black?logo=buymeacoffee
      :target: https://buymeacoffee.com/Tatsh
      :alt: Buy Me A Coffee

   .. image:: https://img.shields.io/badge/Libera.Chat-Tatsh-black?logo=liberadotchat
      :target: irc://irc.libera.chat/Tatsh
      :alt: Libera.Chat

   .. image:: https://img.shields.io/mastodon/follow/109370961877277568?domain=hostux.social&style=social
      :target: https://hostux.social/@Tatsh
      :alt: Mastodon Follow

   .. image:: https://img.shields.io/badge/Patreon-Tatsh2-F96854?logo=patreon
      :target: https://www.patreon.com/Tatsh2
      :alt: Patreon
